aboutsummaryrefslogtreecommitdiffhomepage
path: root/src/core/channel/channel_args.h
diff options
context:
space:
mode:
authorGravatar David Garcia Quintas <dgq@google.com>2015-07-17 15:33:13 -0700
committerGravatar David Garcia Quintas <dgq@google.com>2015-07-17 15:33:13 -0700
commitcadbf22467ef7c636dabec53a0178f1b669ba42e (patch)
tree16fd1996b235209941b7ae3b0ee7abd55af79dc3 /src/core/channel/channel_args.h
parent7c4fdb5628209b47e9099b99b35284005c79f0fa (diff)
Removed compression levels from clients and _experimental_'d signature of methods manipulating compression algorithms
Diffstat (limited to 'src/core/channel/channel_args.h')
-rw-r--r--src/core/channel/channel_args.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/core/channel/channel_args.h b/src/core/channel/channel_args.h
index 17321010c5..7e6ddd3997 100644
--- a/src/core/channel/channel_args.h
+++ b/src/core/channel/channel_args.h
@@ -57,14 +57,14 @@ void grpc_channel_args_destroy(grpc_channel_args *a);
* is specified in channel args, otherwise returns 0. */
int grpc_channel_args_is_census_enabled(const grpc_channel_args *a);
-/** Returns the compression level set in \a a. */
-grpc_compression_level grpc_channel_args_get_compression_level(
+/** Returns the compression algorithm set in \a a. */
+grpc_compression_algorithm grpc_channel_args_get_compression_algorithm(
const grpc_channel_args *a);
/** Returns a channel arg instance with compression enabled. If \a a is
- * non-NULL, its args are copied. N.B. GRPC_COMPRESS_LEVEL_NONE disables
- * compression for the channel. */
-grpc_channel_args *grpc_channel_args_set_compression_level(
- grpc_channel_args *a, grpc_compression_level level);
+ * non-NULL, its args are copied. N.B. GRPC_COMPRESS_NONE disables compression
+ * for the channel. */
+grpc_channel_args *grpc_channel_args_set_compression_algorithm(
+ grpc_channel_args *a, grpc_compression_algorithm algorithm);
#endif /* GRPC_INTERNAL_CORE_CHANNEL_CHANNEL_ARGS_H */